@@ -122,41 +122,28 @@ void usec_sleep(struct thread_data *td, unsigned long usec)
 	} while (!td->terminate);
 }
 
-void rate_throttle(struct thread_data *td, unsigned long time_spent,
-		   unsigned int bytes)
+long rate_throttle(struct thread_data *td, unsigned long time_spent,
+		   unsigned long bytes, enum fio_ddir ddir)
 {
+	unsigned int bs = td->o.min_bs[ddir];
 	unsigned long usec_cycle;
-	unsigned int bs;
 
-	if (!td->o.rate && !td->o.rate_iops)
-		return;
+	if (!td->o.rate[ddir] && !td->o.rate_iops[ddir])
+		return 0;
 
-	if (td_rw(td))
-		bs = td->o.rw_min_bs;
-	else if (td_read(td))
-		bs = td->o.min_bs[DDIR_READ];
-	else
-		bs = td->o.min_bs[DDIR_WRITE];
-
-	usec_cycle = td->rate_usec_cycle * (bytes / bs);
+	usec_cycle = td->rate_usec_cycle[ddir] * (bytes / bs);
 
 	if (time_spent < usec_cycle) {
 		unsigned long s = usec_cycle - time_spent;
 
-		td->rate_pending_usleep += s;
-
-		if (td->rate_pending_usleep >= 100000) {
-			struct timeval t;
-
-			fio_gettime(&t, NULL);
-			usec_sleep(td, td->rate_pending_usleep);
-			td->rate_pending_usleep -= utime_since_now(&t);
-		}
+		td->rate_pending_usleep[ddir] += s;
 	} else {
 		long overtime = time_spent - usec_cycle;
 
-		td->rate_pending_usleep -= overtime;
+		td->rate_pending_usleep[ddir] -= overtime;
 	}
+
+	return td->rate_pending_usleep[ddir];
 }
 
 unsigned long mtime_since_genesis(void)
